// SimSun Shader by Cherno
// November 4th 2023 - converted for VKDoom by Nash Muhandes

const float pi = 3.14159265359;

void SetupMaterial(inout Material mat)
{
	vec3 lightDir = vec3(0.75, -1.0, -0.5);
	// Doom map axis: x, z, y
	// with 1.0-1.0,-1.0, the light comes from the north-west-west diagonally downwards, if north is towards the top of the (auto or editor)map

	vec2 texCoord = vTexCoord.st;
	vec3 l = lightDir;
	vec3 n = normalize(vWorldNormal.xyz);
	float angle = acos
	(
		(l.x * n.x + l.y * n.y + l.z * n.z)
		/
		(
			(
				sqrt
				(
					(l.x * l.x) + (l.y * l.y) + (l.z * l.z)
				)
				*
				sqrt
				(
					(n.x * n.x) + (n.y * n.y) + (n.z * n.z)
				)
			)
		)
	);
	float lightLevel = angle;
	lightLevel /= pi;

	// from here on out, you have a lightLevel between 0.0 and 1.0, depending on the angle of the surface relative to lightDir.
	// a lightLevel of 0.5 results in the pixel at it would appear with no shading from SimSun at all.
	// you can add calculations to the lightvalue if you wish to increase, decrease, or shoft the effect.

	// shifts the lightLevel so it gets slightly lighter, so there are less extremely dark areas
	lightLevel += 0.25;

	mat.Base = getTexel(texCoord) * vec4(lightLevel, lightLevel, lightLevel, 1.0);
}
